@@ -10,103 +10,78 @@
 //
 //
 #include "output.h"
+#include "sys.h"
 
-void pwarning(enum STATE_TYPE state, const char *format, ...)
-{
-#ifdef WARNING
-	va_list ap;
-
-	va_start(ap, format);
-	vwarnx(format, ap);
-	va_end(ap);
-#endif
-	switch (state) {
-	case Quit:
-		exit(1);
-		break;
-	default:
-		break;
-	}
-}
-
-void pmessage(const char *format, ...)
-{
-#ifdef MESSAGE
-	va_list ap;
-
-	va_start(ap, format);
-	vprintf(format, ap);
-	va_end(ap);
-#endif
-}
-
-void ptrace(const char *format, ...)
-{
-#ifdef TRACE
-	va_list ap;
-
-	va_start(ap, format);
-	vprintf(format, ap);
-	va_end(ap);
-#endif
-}
-
-void pop_info(GtkWidget * parent, GtkWidget * fw, const gchar * format, ...)
+/**
+ * 弹出消息提示.
+ * @param parent parent window
+ * @param format as in printf()
+ * @param ...
+ */
+void pop_info(GtkWidget *parent, const gchar *format, ...)
 {
 	GtkWidget *dialog;
-	va_list ap;
 	gchar *msg;
+	va_list ap;
 
 	va_start(ap, format);
 	msg = g_strdup_vprintf(format, ap);
 	va_end(ap);
-	dialog = gtk_message_dialog_new_with_markup(GTK_WINDOW(parent),
-				    GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
-				    GTK_BUTTONS_OK, "%s", msg);
+	dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
+			 GTK_DIALOG_MODAL,  GTK_MESSAGE_INFO,
+			 GTK_BUTTONS_OK, NULL);
+	gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), msg);
 	g_free(msg);
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Infomation"));
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
-
-	if (fw)
-		gtk_widget_grab_focus(fw);
 }
 
-void pop_warning(GtkWidget * parent, GtkWidget * fw, const gchar * format, ...)
+/**
+ * 弹出警告信息.
+ * @param parent parent window
+ * @param format as in printf()
+ * @param ...
+ */
+void pop_warning(GtkWidget *parent, const gchar *format, ...)
 {
 	GtkWidget *dialog;
-	va_list ap;
 	gchar *msg;
+	va_list ap;
 
 	va_start(ap, format);
 	msg = g_strdup_vprintf(format, ap);
 	va_end(ap);
-	dialog = gtk_message_dialog_new_with_markup(GTK_WINDOW(parent),
-				    GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING,
-				    GTK_BUTTONS_OK, "%s", msg);
+	dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
+			 GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
+			 GTK_BUTTONS_OK, NULL);
+	gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), msg);
 	g_free(msg);
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Warning"));
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
-
-	if (fw)
-		gtk_widget_grab_focus(fw);
 }
 
-void pop_error(const gchar * format, ...)
+/**
+ * 严重错误，程序将有可能自行强制退出.
+ * @param format as in printf()
+ * @param ...
+ */
+void pop_error(const gchar *format, ...)
 {
 	GtkWidget *dialog;
-	va_list ap;
 	gchar *msg;
+	va_list ap;
 
 	va_start(ap, format);
 	msg = g_strdup_vprintf(format, ap);
 	va_end(ap);
-	dialog = gtk_message_dialog_new_with_markup(NULL,
-				    GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-				    GTK_BUTTONS_OK, "%s", msg);
+	dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
+			 GTK_MESSAGE_INFO, GTK_BUTTONS_OK, NULL);
+	gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), msg);
 	g_free(msg);
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Error"));
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
 }
+
