@@ -37,15 +37,16 @@
 #include <stdarg.h>
 #include <sys/stat.h>
 #include <sys/time.h>
+#include <sys/queue.h>
 #include <fcntl.h>
 #include <dirent.h>
 #include <ftw.h>
 #include <signal.h>
 #include <sys/vfs.h>
 #include <pwd.h>
+#include <getopt.h>
 #include <locale.h>
 #include <libintl.h>
-typedef void *pointer;
 
 #ifndef _
 #define _(string) gettext(string)
