@@ -11,7 +11,7 @@
 //
 #include "utils.h"
 #include "../sys.h"
-#define MAX_PATHBUF 1024
+#define MAX_PATHLEN 1024
 
 void check_privileged()
 {
@@ -25,14 +25,14 @@ void check_privileged()
 
 void remove_folder(const char *path)
 {
-	char buf[MAX_PATHBUF];
+	char buf[MAX_PATHLEN];
 	struct stat st;
 	struct dirent *dirt;
 	DIR *dir;
 
 	if (!(dir = opendir(path))) {
-		warnx(_("act: open directory '%s',warning: %s\n"),
-				      path, strerror(errno));
+		warnx(_("Opendir() directory \"%s\" failed, %s\n"), path,
+							 strerror(errno));
 		return;
 	}
 
@@ -40,17 +40,16 @@ void remove_folder(const char *path)
 		if ((strcmp(dirt->d_name, ".") == 0)
 			   || (strcmp(dirt->d_name, "..") == 0))
 			continue;
-		snprintf(buf, MAX_PATHBUF, "%s/%s", path, dirt->d_name);
+		snprintf(buf, MAX_PATHLEN, "%s/%s", path, dirt->d_name);
 		if (stat(buf, &st) == -1) {
-			warnx(_("act: look up file's status '%s',warning: %s\n"),
-						      buf, strerror(errno));
+			warnx(_("Stat() file \"%s\" failed, %s\n"), buf, strerror(errno));
 			continue;
 		}
 
 		if (S_ISLNK(st.st_mode) || S_ISREG(st.st_mode)) {
 			if (unlink(buf) == -1)
-				warnx(_("act: unlink file '%s',warning: %s\n"),
-						      buf, strerror(errno));
+				warnx(_("Unlink() file \"%s\" failed, %s\n"), buf,
+								 strerror(errno));
 		}
 		else if (S_ISDIR(st.st_mode)) {
 			remove_folder(buf);
@@ -59,13 +58,11 @@ void remove_folder(const char *path)
 	closedir(dir);
 
 	if (rmdir(path) == -1)
-		warnx(_("act: rmdir directory '%s',warning: %s\n"),
-				      buf, strerror(errno));
+		warnx(_("Rmdir() directory \"%s\" failed, %s\n"), buf, strerror(errno));
 }
 
 void remove_file(const char *path)
 {
 	if (unlink(path) == -1)
-		warnx(_("act: unlink file '%s',warning: %s\n"),
-				      path, strerror(errno));
+		warnx(_("Unlink() file \"%s\" failed, %s\n"), path, strerror(errno));
 }
